@@ -15,9 +15,8 @@ use base qw( Class::Accessor::Chained::Fast );
 __PACKAGE__->mk_accessors(qw( endpoint ));
 
 use LWP::UserAgent;
-use JSON::XS qw( from_json );
+use JSON::Syck;
 use HTTP::Request::Common;
-use Encode qw( encode_utf8 );
 
 =head1 ATTRIBUTES
 
@@ -31,9 +30,7 @@ use Encode qw( encode_utf8 );
 
 =over
 
-=item new( endpoint, [ timeout => 30 ] )
-
-We take an endpoint here. Optionally, we also take a timeout in seconds.
+=item new( endpoint )
 
 =cut
 
@@ -41,7 +38,7 @@ sub new {
   my $class = shift;
   my $endpoint = shift;
   my $self = $class->SUPER::new({ endpoint => $endpoint });
-  $self->{ua} = LWP::UserAgent->new( @_ );
+  $self->{ua} = LWP::UserAgent->new();
   return $self;
 }
 
@@ -53,46 +50,13 @@ sub call {
   my $self = shift;
   my $method = shift;
   my %args = ref $_[0] eq 'HASH' ? %{ $_[0] } : @_;
-
-  # we want json
-  $args{_type} = "json";
-
-  my $response = $self->call_raw($method, %args);
-  # parse as Frooy/JSON response
-  my $data = eval { from_json( $response ) };
-  unless (ref $data eq "HASH") {
-    die "Error parsing ".$response.": $@";
-  }
-  unless ($data->{stat} eq 'ok') {
-    my $error = $data->{data};
-    Froody::Error->throw(delete $error->{code}, delete $error->{msg}, $error);
-  }
-  return $data->{data};
-}
-
-=item call_raw( method, args )
-
-makes a raw call, returns the exact thing returned by the server.
-
-=cut
-
-sub call_raw {
-  my $self = shift;
-  my $method = shift;
-  my %args = ref $_[0] eq 'HASH' ? %{ $_[0] } : @_;
   
   die "no endpoint set" unless $self->endpoint;
   die "no UA" unless $self->{ua};
 
   # fudge args so we can do the Right Thing with lists and uploads.
-  my $hash_expansion;
   for (keys %args) {
     my $value = $args{$_};
-    if (!defined $value) {
-      delete $args{$_};
-      next;
-    }
-
     my $ref = ref($value);
     if ($ref eq 'ARRAY' and ref $value->[0] eq 'Froody::Upload') {
       # upload
@@ -103,35 +67,33 @@ sub call_raw {
       # just CSV
       $args{$_} = join(",", @$value );
 
-    } elsif ($ref eq 'HASH') {
-      die "too many arguments of type 'remaining'; previous was '$hash_expansion' and current is '$_'"
-        if $hash_expansion;
-      $hash_expansion = $_;
-      my $blah = delete $args{$_};
-      %args = ( %args, %$blah );
-
-    } elsif ($ref) {
+    } elsif (ref($args{$_})) {
       die "can't handle type of argument '$_' (is a ".ref($args{$_}).")";
     }
+    delete $args{$_} unless defined $args{$_};
   }
-  
-  my @args = %args;
-  @args = map { ref($_) ? $_ : Encode::encode('utf-8', $_) } @args;
-  %args = @args;
 
   # make the request
   my $request = POST( $self->endpoint,
     Content_Type => 'form-data',
-    Content => [ method => $method, %args ] );
-
+    Content => [ method => $method, _froody_type => "json", %args ] );
   my $response = $self->{ua}->request( $request );
 
   Froody::Error->throw('froody.invoke.remote', 'Bad response from server: '. $response->status_line)
     unless $response->is_success;
 
-  return $response->content;
+  # parse as Frooy/JSON response
+  my $data = eval { JSON::Syck::Load( $response->content ) };
+  unless (ref $data eq "HASH") {
+    die "Error parsing ".$response->content.": $@";
+  }
+  unless ($data->{stat} eq 'ok') {
+    Froody::Error->throw($data->{data}{code}, $data->{data}{msg}, $data->{data}{error});
+  }
+  return $data->{data};
 }
 
+
 =back
 
 =head1 AUTHOR
