@@ -7,12 +7,9 @@ use warnings;
 
 sub implements { DTest => "foo.test.*" }
 
-sub sloooow { sleep 300; die 'should never get here' }
 
 sub add { return { '-text' => "\x{e9}" } }
 
-sub echo { return { '-text' => $_[1]->{echo} } }
-
 sub getGroups { return { '-text' => "\x{2264}" } }
 
 sub thunktest { 
@@ -34,19 +31,10 @@ sub badhandler {
   Froody::Error->throw('test.badhandler.tripwire', "I'm just a catalyst for bad things");
 }
 
-sub badspec {
-  return { bar => [1,2,3] };
-}
-
 sub error_handler {
   my ($self,$method, $error, $data) = @_;
   die "This shouldn't kill froody" if $method->name =~ /badhandler/;
   return $self->SUPER::error_handler($method, $error, $data);
 }
 
-sub remaining {
-  my ($self, $args) = @_;
-  return length( [ keys %{ $args->{remaining} } ]->[0] );
-}
-
 1;
